"""
Type annotations for lookoutmetrics service Client.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from types_boto3_lookoutmetrics.client import LookoutMetricsClient

    session = Session()
    client: LookoutMetricsClient = session.client("lookoutmetrics")
    ```
"""

from __future__ import annotations

import sys
from typing import Any

from botocore.client import BaseClient, ClientMeta
from botocore.errorfactory import BaseClientExceptions
from botocore.exceptions import ClientError as BotocoreClientError

from .type_defs import (
    ActivateAnomalyDetectorRequestTypeDef,
    BackTestAnomalyDetectorRequestTypeDef,
    CreateAlertRequestTypeDef,
    CreateAlertResponseTypeDef,
    CreateAnomalyDetectorRequestTypeDef,
    CreateAnomalyDetectorResponseTypeDef,
    CreateMetricSetRequestTypeDef,
    CreateMetricSetResponseTypeDef,
    DeactivateAnomalyDetectorRequestTypeDef,
    DeleteAlertRequestTypeDef,
    DeleteAnomalyDetectorRequestTypeDef,
    DescribeAlertRequestTypeDef,
    DescribeAlertResponseTypeDef,
    DescribeAnomalyDetectionExecutionsRequestTypeDef,
    DescribeAnomalyDetectionExecutionsResponseTypeDef,
    DescribeAnomalyDetectorRequestTypeDef,
    DescribeAnomalyDetectorResponseTypeDef,
    DescribeMetricSetRequestTypeDef,
    DescribeMetricSetResponseTypeDef,
    DetectMetricSetConfigRequestTypeDef,
    DetectMetricSetConfigResponseTypeDef,
    GetAnomalyGroupRequestTypeDef,
    GetAnomalyGroupResponseTypeDef,
    GetDataQualityMetricsRequestTypeDef,
    GetDataQualityMetricsResponseTypeDef,
    GetFeedbackRequestTypeDef,
    GetFeedbackResponseTypeDef,
    GetSampleDataRequestTypeDef,
    GetSampleDataResponseTypeDef,
    ListAlertsRequestTypeDef,
    ListAlertsResponseTypeDef,
    ListAnomalyDetectorsRequestTypeDef,
    ListAnomalyDetectorsResponseTypeDef,
    ListAnomalyGroupRelatedMetricsRequestTypeDef,
    ListAnomalyGroupRelatedMetricsResponseTypeDef,
    ListAnomalyGroupSummariesRequestTypeDef,
    ListAnomalyGroupSummariesResponseTypeDef,
    ListAnomalyGroupTimeSeriesRequestTypeDef,
    ListAnomalyGroupTimeSeriesResponseTypeDef,
    ListMetricSetsRequestTypeDef,
    ListMetricSetsResponseTypeDef,
    ListTagsForResourceRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    PutFeedbackRequestTypeDef,
    TagResourceRequestTypeDef,
    UntagResourceRequestTypeDef,
    UpdateAlertRequestTypeDef,
    UpdateAlertResponseTypeDef,
    UpdateAnomalyDetectorRequestTypeDef,
    UpdateAnomalyDetectorResponseTypeDef,
    UpdateMetricSetRequestTypeDef,
    UpdateMetricSetResponseTypeDef,
)

if sys.version_info >= (3, 9):
    from builtins import dict as Dict
    from builtins import type as Type
    from collections.abc import Mapping
else:
    from typing import Dict, Mapping, Type
if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack

__all__ = ("LookoutMetricsClient",)

class Exceptions(BaseClientExceptions):
    AccessDeniedException: Type[BotocoreClientError]
    ClientError: Type[BotocoreClientError]
    ConflictException: Type[BotocoreClientError]
    InternalServerException: Type[BotocoreClientError]
    ResourceNotFoundException: Type[BotocoreClientError]
    ServiceQuotaExceededException: Type[BotocoreClientError]
    TooManyRequestsException: Type[BotocoreClientError]
    ValidationException: Type[BotocoreClientError]

class LookoutMetricsClient(BaseClient):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics.html#LookoutMetrics.Client)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/)
    """

    meta: ClientMeta

    @property
    def exceptions(self) -> Exceptions:
        """
        LookoutMetricsClient exceptions.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics.html#LookoutMetrics.Client)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#exceptions)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/can_paginate.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#can_paginate)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Mapping[str, Any] = ...,
        ExpiresIn: int = 3600,
        HttpMethod: str = ...,
    ) -> str:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/generate_presigned_url.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#generate_presigned_url)
        """

    def activate_anomaly_detector(
        self, **kwargs: Unpack[ActivateAnomalyDetectorRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Activates an anomaly detector.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/activate_anomaly_detector.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#activate_anomaly_detector)
        """

    def back_test_anomaly_detector(
        self, **kwargs: Unpack[BackTestAnomalyDetectorRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Runs a backtest for anomaly detection for the specified resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/back_test_anomaly_detector.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#back_test_anomaly_detector)
        """

    def create_alert(
        self, **kwargs: Unpack[CreateAlertRequestTypeDef]
    ) -> CreateAlertResponseTypeDef:
        """
        Creates an alert for an anomaly detector.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/create_alert.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#create_alert)
        """

    def create_anomaly_detector(
        self, **kwargs: Unpack[CreateAnomalyDetectorRequestTypeDef]
    ) -> CreateAnomalyDetectorResponseTypeDef:
        """
        Creates an anomaly detector.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/create_anomaly_detector.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#create_anomaly_detector)
        """

    def create_metric_set(
        self, **kwargs: Unpack[CreateMetricSetRequestTypeDef]
    ) -> CreateMetricSetResponseTypeDef:
        """
        Creates a dataset.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/create_metric_set.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#create_metric_set)
        """

    def deactivate_anomaly_detector(
        self, **kwargs: Unpack[DeactivateAnomalyDetectorRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Deactivates an anomaly detector.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/deactivate_anomaly_detector.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#deactivate_anomaly_detector)
        """

    def delete_alert(self, **kwargs: Unpack[DeleteAlertRequestTypeDef]) -> Dict[str, Any]:
        """
        Deletes an alert.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/delete_alert.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#delete_alert)
        """

    def delete_anomaly_detector(
        self, **kwargs: Unpack[DeleteAnomalyDetectorRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Deletes a detector.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/delete_anomaly_detector.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#delete_anomaly_detector)
        """

    def describe_alert(
        self, **kwargs: Unpack[DescribeAlertRequestTypeDef]
    ) -> DescribeAlertResponseTypeDef:
        """
        Describes an alert.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/describe_alert.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#describe_alert)
        """

    def describe_anomaly_detection_executions(
        self, **kwargs: Unpack[DescribeAnomalyDetectionExecutionsRequestTypeDef]
    ) -> DescribeAnomalyDetectionExecutionsResponseTypeDef:
        """
        Returns information about the status of the specified anomaly detection jobs.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/describe_anomaly_detection_executions.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#describe_anomaly_detection_executions)
        """

    def describe_anomaly_detector(
        self, **kwargs: Unpack[DescribeAnomalyDetectorRequestTypeDef]
    ) -> DescribeAnomalyDetectorResponseTypeDef:
        """
        Describes a detector.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/describe_anomaly_detector.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#describe_anomaly_detector)
        """

    def describe_metric_set(
        self, **kwargs: Unpack[DescribeMetricSetRequestTypeDef]
    ) -> DescribeMetricSetResponseTypeDef:
        """
        Describes a dataset.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/describe_metric_set.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#describe_metric_set)
        """

    def detect_metric_set_config(
        self, **kwargs: Unpack[DetectMetricSetConfigRequestTypeDef]
    ) -> DetectMetricSetConfigResponseTypeDef:
        """
        Detects an Amazon S3 dataset's file format, interval, and offset.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/detect_metric_set_config.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#detect_metric_set_config)
        """

    def get_anomaly_group(
        self, **kwargs: Unpack[GetAnomalyGroupRequestTypeDef]
    ) -> GetAnomalyGroupResponseTypeDef:
        """
        Returns details about a group of anomalous metrics.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/get_anomaly_group.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#get_anomaly_group)
        """

    def get_data_quality_metrics(
        self, **kwargs: Unpack[GetDataQualityMetricsRequestTypeDef]
    ) -> GetDataQualityMetricsResponseTypeDef:
        """
        Returns details about the requested data quality metrics.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/get_data_quality_metrics.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#get_data_quality_metrics)
        """

    def get_feedback(
        self, **kwargs: Unpack[GetFeedbackRequestTypeDef]
    ) -> GetFeedbackResponseTypeDef:
        """
        Get feedback for an anomaly group.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/get_feedback.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#get_feedback)
        """

    def get_sample_data(
        self, **kwargs: Unpack[GetSampleDataRequestTypeDef]
    ) -> GetSampleDataResponseTypeDef:
        """
        Returns a selection of sample records from an Amazon S3 datasource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/get_sample_data.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#get_sample_data)
        """

    def list_alerts(self, **kwargs: Unpack[ListAlertsRequestTypeDef]) -> ListAlertsResponseTypeDef:
        """
        Lists the alerts attached to a detector.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/list_alerts.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#list_alerts)
        """

    def list_anomaly_detectors(
        self, **kwargs: Unpack[ListAnomalyDetectorsRequestTypeDef]
    ) -> ListAnomalyDetectorsResponseTypeDef:
        """
        Lists the detectors in the current AWS Region.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/list_anomaly_detectors.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#list_anomaly_detectors)
        """

    def list_anomaly_group_related_metrics(
        self, **kwargs: Unpack[ListAnomalyGroupRelatedMetricsRequestTypeDef]
    ) -> ListAnomalyGroupRelatedMetricsResponseTypeDef:
        """
        Returns a list of measures that are potential causes or effects of an anomaly
        group.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/list_anomaly_group_related_metrics.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#list_anomaly_group_related_metrics)
        """

    def list_anomaly_group_summaries(
        self, **kwargs: Unpack[ListAnomalyGroupSummariesRequestTypeDef]
    ) -> ListAnomalyGroupSummariesResponseTypeDef:
        """
        Returns a list of anomaly groups.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/list_anomaly_group_summaries.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#list_anomaly_group_summaries)
        """

    def list_anomaly_group_time_series(
        self, **kwargs: Unpack[ListAnomalyGroupTimeSeriesRequestTypeDef]
    ) -> ListAnomalyGroupTimeSeriesResponseTypeDef:
        """
        Gets a list of anomalous metrics for a measure in an anomaly group.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/list_anomaly_group_time_series.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#list_anomaly_group_time_series)
        """

    def list_metric_sets(
        self, **kwargs: Unpack[ListMetricSetsRequestTypeDef]
    ) -> ListMetricSetsResponseTypeDef:
        """
        Lists the datasets in the current AWS Region.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/list_metric_sets.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#list_metric_sets)
        """

    def list_tags_for_resource(
        self, **kwargs: Unpack[ListTagsForResourceRequestTypeDef]
    ) -> ListTagsForResourceResponseTypeDef:
        """
        Gets a list of <a
        href="https://docs.aws.amazon.com/lookoutmetrics/latest/dev/detectors-tags.html">tags</a>
        for a detector, dataset, or alert.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/list_tags_for_resource.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#list_tags_for_resource)
        """

    def put_feedback(self, **kwargs: Unpack[PutFeedbackRequestTypeDef]) -> Dict[str, Any]:
        """
        Add feedback for an anomalous metric.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/put_feedback.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#put_feedback)
        """

    def tag_resource(self, **kwargs: Unpack[TagResourceRequestTypeDef]) -> Dict[str, Any]:
        """
        Adds <a
        href="https://docs.aws.amazon.com/lookoutmetrics/latest/dev/detectors-tags.html">tags</a>
        to a detector, dataset, or alert.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/tag_resource.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#tag_resource)
        """

    def untag_resource(self, **kwargs: Unpack[UntagResourceRequestTypeDef]) -> Dict[str, Any]:
        """
        Removes <a
        href="https://docs.aws.amazon.com/lookoutmetrics/latest/dev/detectors-tags.html">tags</a>
        from a detector, dataset, or alert.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/untag_resource.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#untag_resource)
        """

    def update_alert(
        self, **kwargs: Unpack[UpdateAlertRequestTypeDef]
    ) -> UpdateAlertResponseTypeDef:
        """
        Make changes to an existing alert.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/update_alert.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#update_alert)
        """

    def update_anomaly_detector(
        self, **kwargs: Unpack[UpdateAnomalyDetectorRequestTypeDef]
    ) -> UpdateAnomalyDetectorResponseTypeDef:
        """
        Updates a detector.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/update_anomaly_detector.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#update_anomaly_detector)
        """

    def update_metric_set(
        self, **kwargs: Unpack[UpdateMetricSetRequestTypeDef]
    ) -> UpdateMetricSetResponseTypeDef:
        """
        Updates a dataset.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/lookoutmetrics/client/update_metric_set.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/client/#update_metric_set)
        """



"""
Main interface for lookoutmetrics service.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from types_boto3_lookoutmetrics import (
        Client,
        LookoutMetricsClient,
    )

    session = Session()
    client: LookoutMetricsClient = session.client("lookoutmetrics")
    ```
"""

from .client import LookoutMetricsClient

Client = LookoutMetricsClient


__all__ = ("Client", "LookoutMetricsClient")



"""
Type annotations for lookoutmetrics service type definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_lookoutmetrics/type_defs/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from types_boto3_lookoutmetrics.type_defs import LambdaConfigurationTypeDef

    data: LambdaConfigurationTypeDef = ...
    ```
"""

from __future__ import annotations

import sys
from datetime import datetime
from typing import Union

from .literals import (
    AggregationFunctionType,
    AlertStatusType,
    AlertTypeType,
    AnomalyDetectionTaskStatusType,
    AnomalyDetectorFailureTypeType,
    AnomalyDetectorStatusType,
    ConfidenceType,
    CSVFileCompressionType,
    DataQualityMetricTypeType,
    FrequencyType,
    JsonFileCompressionType,
    RelationshipTypeType,
    SnsFormatType,
)

if sys.version_info >= (3, 9):
    from builtins import dict as Dict
    from builtins import list as List
    from collections.abc import Mapping, Sequence
else:
    from typing import Dict, List, Mapping, Sequence
if sys.version_info >= (3, 12):
    from typing import Literal, NotRequired, TypedDict
else:
    from typing_extensions import Literal, NotRequired, TypedDict


__all__ = (
    "ActionTypeDef",
    "ActivateAnomalyDetectorRequestTypeDef",
    "AlertFiltersOutputTypeDef",
    "AlertFiltersTypeDef",
    "AlertFiltersUnionTypeDef",
    "AlertSummaryTypeDef",
    "AlertTypeDef",
    "AnomalyDetectorConfigSummaryTypeDef",
    "AnomalyDetectorConfigTypeDef",
    "AnomalyDetectorDataQualityMetricTypeDef",
    "AnomalyDetectorSummaryTypeDef",
    "AnomalyGroupStatisticsTypeDef",
    "AnomalyGroupSummaryTypeDef",
    "AnomalyGroupTimeSeriesFeedbackTypeDef",
    "AnomalyGroupTimeSeriesTypeDef",
    "AnomalyGroupTypeDef",
    "AppFlowConfigTypeDef",
    "AthenaSourceConfigTypeDef",
    "AttributeValueTypeDef",
    "AutoDetectionMetricSourceTypeDef",
    "AutoDetectionS3SourceConfigTypeDef",
    "BackTestAnomalyDetectorRequestTypeDef",
    "BackTestConfigurationTypeDef",
    "CloudWatchConfigTypeDef",
    "ContributionMatrixTypeDef",
    "CreateAlertRequestTypeDef",
    "CreateAlertResponseTypeDef",
    "CreateAnomalyDetectorRequestTypeDef",
    "CreateAnomalyDetectorResponseTypeDef",
    "CreateMetricSetRequestTypeDef",
    "CreateMetricSetResponseTypeDef",
    "CsvFormatDescriptorOutputTypeDef",
    "CsvFormatDescriptorTypeDef",
    "CsvFormatDescriptorUnionTypeDef",
    "DataQualityMetricTypeDef",
    "DeactivateAnomalyDetectorRequestTypeDef",
    "DeleteAlertRequestTypeDef",
    "DeleteAnomalyDetectorRequestTypeDef",
    "DescribeAlertRequestTypeDef",
    "DescribeAlertResponseTypeDef",
    "DescribeAnomalyDetectionExecutionsRequestTypeDef",
    "DescribeAnomalyDetectionExecutionsResponseTypeDef",
    "DescribeAnomalyDetectorRequestTypeDef",
    "DescribeAnomalyDetectorResponseTypeDef",
    "DescribeMetricSetRequestTypeDef",
    "DescribeMetricSetResponseTypeDef",
    "DetectMetricSetConfigRequestTypeDef",
    "DetectMetricSetConfigResponseTypeDef",
    "DetectedCsvFormatDescriptorTypeDef",
    "DetectedFieldTypeDef",
    "DetectedFileFormatDescriptorTypeDef",
    "DetectedJsonFormatDescriptorTypeDef",
    "DetectedMetricSetConfigTypeDef",
    "DetectedMetricSourceTypeDef",
    "DetectedS3SourceConfigTypeDef",
    "DimensionContributionTypeDef",
    "DimensionFilterOutputTypeDef",
    "DimensionFilterTypeDef",
    "DimensionNameValueTypeDef",
    "DimensionValueContributionTypeDef",
    "ExecutionStatusTypeDef",
    "FileFormatDescriptorOutputTypeDef",
    "FileFormatDescriptorTypeDef",
    "FileFormatDescriptorUnionTypeDef",
    "FilterTypeDef",
    "GetAnomalyGroupRequestTypeDef",
    "GetAnomalyGroupResponseTypeDef",
    "GetDataQualityMetricsRequestTypeDef",
    "GetDataQualityMetricsResponseTypeDef",
    "GetFeedbackRequestTypeDef",
    "GetFeedbackResponseTypeDef",
    "GetSampleDataRequestTypeDef",
    "GetSampleDataResponseTypeDef",
    "InterMetricImpactDetailsTypeDef",
    "ItemizedMetricStatsTypeDef",
    "JsonFormatDescriptorTypeDef",
    "LambdaConfigurationTypeDef",
    "ListAlertsRequestTypeDef",
    "ListAlertsResponseTypeDef",
    "ListAnomalyDetectorsRequestTypeDef",
    "ListAnomalyDetectorsResponseTypeDef",
    "ListAnomalyGroupRelatedMetricsRequestTypeDef",
    "ListAnomalyGroupRelatedMetricsResponseTypeDef",
    "ListAnomalyGroupSummariesRequestTypeDef",
    "ListAnomalyGroupSummariesResponseTypeDef",
    "ListAnomalyGroupTimeSeriesRequestTypeDef",
    "ListAnomalyGroupTimeSeriesResponseTypeDef",
    "ListMetricSetsRequestTypeDef",
    "ListMetricSetsResponseTypeDef",
    "ListTagsForResourceRequestTypeDef",
    "ListTagsForResourceResponseTypeDef",
    "MetricLevelImpactTypeDef",
    "MetricSetDataQualityMetricTypeDef",
    "MetricSetDimensionFilterOutputTypeDef",
    "MetricSetDimensionFilterTypeDef",
    "MetricSetDimensionFilterUnionTypeDef",
    "MetricSetSummaryTypeDef",
    "MetricSourceOutputTypeDef",
    "MetricSourceTypeDef",
    "MetricSourceUnionTypeDef",
    "MetricTypeDef",
    "PutFeedbackRequestTypeDef",
    "RDSSourceConfigOutputTypeDef",
    "RDSSourceConfigTypeDef",
    "RedshiftSourceConfigOutputTypeDef",
    "RedshiftSourceConfigTypeDef",
    "ResponseMetadataTypeDef",
    "S3SourceConfigOutputTypeDef",
    "S3SourceConfigTypeDef",
    "SNSConfigurationTypeDef",
    "SampleDataS3SourceConfigTypeDef",
    "TagResourceRequestTypeDef",
    "TimeSeriesFeedbackTypeDef",
    "TimeSeriesTypeDef",
    "TimestampColumnTypeDef",
    "UntagResourceRequestTypeDef",
    "UpdateAlertRequestTypeDef",
    "UpdateAlertResponseTypeDef",
    "UpdateAnomalyDetectorRequestTypeDef",
    "UpdateAnomalyDetectorResponseTypeDef",
    "UpdateMetricSetRequestTypeDef",
    "UpdateMetricSetResponseTypeDef",
    "VpcConfigurationOutputTypeDef",
    "VpcConfigurationTypeDef",
)


class LambdaConfigurationTypeDef(TypedDict):
    RoleArn: str
    LambdaArn: str


class SNSConfigurationTypeDef(TypedDict):
    RoleArn: str
    SnsTopicArn: str
    SnsFormat: NotRequired[SnsFormatType]


class ActivateAnomalyDetectorRequestTypeDef(TypedDict):
    AnomalyDetectorArn: str


class DimensionFilterOutputTypeDef(TypedDict):
    DimensionName: NotRequired[str]
    DimensionValueList: NotRequired[List[str]]


class DimensionFilterTypeDef(TypedDict):
    DimensionName: NotRequired[str]
    DimensionValueList: NotRequired[Sequence[str]]


class AlertSummaryTypeDef(TypedDict):
    AlertArn: NotRequired[str]
    AnomalyDetectorArn: NotRequired[str]
    AlertName: NotRequired[str]
    AlertSensitivityThreshold: NotRequired[int]
    AlertType: NotRequired[AlertTypeType]
    AlertStatus: NotRequired[AlertStatusType]
    LastModificationTime: NotRequired[datetime]
    CreationTime: NotRequired[datetime]
    Tags: NotRequired[Dict[str, str]]


class AnomalyDetectorConfigSummaryTypeDef(TypedDict):
    AnomalyDetectorFrequency: NotRequired[FrequencyType]


class AnomalyDetectorConfigTypeDef(TypedDict):
    AnomalyDetectorFrequency: NotRequired[FrequencyType]


class AnomalyDetectorSummaryTypeDef(TypedDict):
    AnomalyDetectorArn: NotRequired[str]
    AnomalyDetectorName: NotRequired[str]
    AnomalyDetectorDescription: NotRequired[str]
    CreationTime: NotRequired[datetime]
    LastModificationTime: NotRequired[datetime]
    Status: NotRequired[AnomalyDetectorStatusType]
    Tags: NotRequired[Dict[str, str]]


class ItemizedMetricStatsTypeDef(TypedDict):
    MetricName: NotRequired[str]
    OccurrenceCount: NotRequired[int]


class AnomalyGroupSummaryTypeDef(TypedDict):
    StartTime: NotRequired[str]
    EndTime: NotRequired[str]
    AnomalyGroupId: NotRequired[str]
    AnomalyGroupScore: NotRequired[float]
    PrimaryMetricName: NotRequired[str]


class AnomalyGroupTimeSeriesFeedbackTypeDef(TypedDict):
    AnomalyGroupId: str
    TimeSeriesId: str
    IsAnomaly: bool


class AnomalyGroupTimeSeriesTypeDef(TypedDict):
    AnomalyGroupId: str
    TimeSeriesId: NotRequired[str]


class AppFlowConfigTypeDef(TypedDict):
    RoleArn: NotRequired[str]
    FlowName: NotRequired[str]


class BackTestConfigurationTypeDef(TypedDict):
    RunBackTestMode: bool


class AttributeValueTypeDef(TypedDict):
    S: NotRequired[str]
    N: NotRequired[str]
    B: NotRequired[str]
    SS: NotRequired[List[str]]
    NS: NotRequired[List[str]]
    BS: NotRequired[List[str]]


class AutoDetectionS3SourceConfigTypeDef(TypedDict):
    TemplatedPathList: NotRequired[Sequence[str]]
    HistoricalDataPathList: NotRequired[Sequence[str]]


class BackTestAnomalyDetectorRequestTypeDef(TypedDict):
    AnomalyDetectorArn: str


class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: Dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]


class MetricTypeDef(TypedDict):
    MetricName: str
    AggregationFunction: AggregationFunctionType
    Namespace: NotRequired[str]


class TimestampColumnTypeDef(TypedDict):
    ColumnName: NotRequired[str]
    ColumnFormat: NotRequired[str]


class CsvFormatDescriptorOutputTypeDef(TypedDict):
    FileCompression: NotRequired[CSVFileCompressionType]
    Charset: NotRequired[str]
    ContainsHeader: NotRequired[bool]
    Delimiter: NotRequired[str]
    HeaderList: NotRequired[List[str]]
    QuoteSymbol: NotRequired[str]


class CsvFormatDescriptorTypeDef(TypedDict):
    FileCompression: NotRequired[CSVFileCompressionType]
    Charset: NotRequired[str]
    ContainsHeader: NotRequired[bool]
    Delimiter: NotRequired[str]
    HeaderList: NotRequired[Sequence[str]]
    QuoteSymbol: NotRequired[str]


class DataQualityMetricTypeDef(TypedDict):
    MetricType: NotRequired[DataQualityMetricTypeType]
    MetricDescription: NotRequired[str]
    RelatedColumnName: NotRequired[str]
    MetricValue: NotRequired[float]


class DeactivateAnomalyDetectorRequestTypeDef(TypedDict):
    AnomalyDetectorArn: str


class DeleteAlertRequestTypeDef(TypedDict):
    AlertArn: str


class DeleteAnomalyDetectorRequestTypeDef(TypedDict):
    AnomalyDetectorArn: str


class DescribeAlertRequestTypeDef(TypedDict):
    AlertArn: str


class DescribeAnomalyDetectionExecutionsRequestTypeDef(TypedDict):
    AnomalyDetectorArn: str
    Timestamp: NotRequired[str]
    MaxResults: NotRequired[int]
    NextToken: NotRequired[str]


class ExecutionStatusTypeDef(TypedDict):
    Timestamp: NotRequired[str]
    Status: NotRequired[AnomalyDetectionTaskStatusType]
    FailureReason: NotRequired[str]


class DescribeAnomalyDetectorRequestTypeDef(TypedDict):
    AnomalyDetectorArn: str


class DescribeMetricSetRequestTypeDef(TypedDict):
    MetricSetArn: str


class DimensionValueContributionTypeDef(TypedDict):
    DimensionValue: NotRequired[str]
    ContributionScore: NotRequired[float]


class DimensionNameValueTypeDef(TypedDict):
    DimensionName: str
    DimensionValue: str


class JsonFormatDescriptorTypeDef(TypedDict):
    FileCompression: NotRequired[JsonFileCompressionType]
    Charset: NotRequired[str]


class FilterTypeDef(TypedDict):
    DimensionValue: NotRequired[str]
    FilterOperation: NotRequired[Literal["EQUALS"]]


class GetAnomalyGroupRequestTypeDef(TypedDict):
    AnomalyGroupId: str
    AnomalyDetectorArn: str


class GetDataQualityMetricsRequestTypeDef(TypedDict):
    AnomalyDetectorArn: str
    MetricSetArn: NotRequired[str]


class TimeSeriesFeedbackTypeDef(TypedDict):
    TimeSeriesId: NotRequired[str]
    IsAnomaly: NotRequired[bool]


class InterMetricImpactDetailsTypeDef(TypedDict):
    MetricName: NotRequired[str]
    AnomalyGroupId: NotRequired[str]
    RelationshipType: NotRequired[RelationshipTypeType]
    ContributionPercentage: NotRequired[float]


class ListAlertsRequestTypeDef(TypedDict):
    AnomalyDetectorArn: NotRequired[str]
    NextToken: NotRequired[str]
    MaxResults: NotRequired[int]


class ListAnomalyDetectorsRequestTypeDef(TypedDict):
    MaxResults: NotRequired[int]
    NextToken: NotRequired[str]


class ListAnomalyGroupRelatedMetricsRequestTypeDef(TypedDict):
    AnomalyDetectorArn: str
    AnomalyGroupId: str
    RelationshipTypeFilter: NotRequired[RelationshipTypeType]
    MaxResults: NotRequired[int]
    NextToken: NotRequired[str]


class ListAnomalyGroupSummariesRequestTypeDef(TypedDict):
    AnomalyDetectorArn: str
    SensitivityThreshold: int
    MaxResults: NotRequired[int]
    NextToken: NotRequired[str]


class ListAnomalyGroupTimeSeriesRequestTypeDef(TypedDict):
    AnomalyDetectorArn: str
    AnomalyGroupId: str
    MetricName: str
    MaxResults: NotRequired[int]
    NextToken: NotRequired[str]


class ListMetricSetsRequestTypeDef(TypedDict):
    AnomalyDetectorArn: NotRequired[str]
    MaxResults: NotRequired[int]
    NextToken: NotRequired[str]


class MetricSetSummaryTypeDef(TypedDict):
    MetricSetArn: NotRequired[str]
    AnomalyDetectorArn: NotRequired[str]
    MetricSetDescription: NotRequired[str]
    MetricSetName: NotRequired[str]
    CreationTime: NotRequired[datetime]
    LastModificationTime: NotRequired[datetime]
    Tags: NotRequired[Dict[str, str]]


class ListTagsForResourceRequestTypeDef(TypedDict):
    ResourceArn: str


class VpcConfigurationOutputTypeDef(TypedDict):
    SubnetIdList: List[str]
    SecurityGroupIdList: List[str]


class VpcConfigurationTypeDef(TypedDict):
    SubnetIdList: Sequence[str]
    SecurityGroupIdList: Sequence[str]


class TagResourceRequestTypeDef(TypedDict):
    ResourceArn: str
    Tags: Mapping[str, str]


class UntagResourceRequestTypeDef(TypedDict):
    ResourceArn: str
    TagKeys: Sequence[str]


class ActionTypeDef(TypedDict):
    SNSConfiguration: NotRequired[SNSConfigurationTypeDef]
    LambdaConfiguration: NotRequired[LambdaConfigurationTypeDef]


class AlertFiltersOutputTypeDef(TypedDict):
    MetricList: NotRequired[List[str]]
    DimensionFilterList: NotRequired[List[DimensionFilterOutputTypeDef]]


class AlertFiltersTypeDef(TypedDict):
    MetricList: NotRequired[Sequence[str]]
    DimensionFilterList: NotRequired[Sequence[DimensionFilterTypeDef]]


class CreateAnomalyDetectorRequestTypeDef(TypedDict):
    AnomalyDetectorName: str
    AnomalyDetectorConfig: AnomalyDetectorConfigTypeDef
    AnomalyDetectorDescription: NotRequired[str]
    KmsKeyArn: NotRequired[str]
    Tags: NotRequired[Mapping[str, str]]


class UpdateAnomalyDetectorRequestTypeDef(TypedDict):
    AnomalyDetectorArn: str
    KmsKeyArn: NotRequired[str]
    AnomalyDetectorDescription: NotRequired[str]
    AnomalyDetectorConfig: NotRequired[AnomalyDetectorConfigTypeDef]


class AnomalyGroupStatisticsTypeDef(TypedDict):
    EvaluationStartDate: NotRequired[str]
    TotalCount: NotRequired[int]
    ItemizedMetricStatsList: NotRequired[List[ItemizedMetricStatsTypeDef]]


class PutFeedbackRequestTypeDef(TypedDict):
    AnomalyDetectorArn: str
    AnomalyGroupTimeSeriesFeedback: AnomalyGroupTimeSeriesFeedbackTypeDef


class GetFeedbackRequestTypeDef(TypedDict):
    AnomalyDetectorArn: str
    AnomalyGroupTimeSeriesFeedback: AnomalyGroupTimeSeriesTypeDef
    MaxResults: NotRequired[int]
    NextToken: NotRequired[str]


class AthenaSourceConfigTypeDef(TypedDict):
    RoleArn: NotRequired[str]
    DatabaseName: NotRequired[str]
    DataCatalog: NotRequired[str]
    TableName: NotRequired[str]
    WorkGroupName: NotRequired[str]
    S3ResultsPath: NotRequired[str]
    BackTestConfiguration: NotRequired[BackTestConfigurationTypeDef]


class CloudWatchConfigTypeDef(TypedDict):
    RoleArn: NotRequired[str]
    BackTestConfiguration: NotRequired[BackTestConfigurationTypeDef]


class DetectedFieldTypeDef(TypedDict):
    Value: NotRequired[AttributeValueTypeDef]
    Confidence: NotRequired[ConfidenceType]
    Message: NotRequired[str]


class AutoDetectionMetricSourceTypeDef(TypedDict):
    S3SourceConfig: NotRequired[AutoDetectionS3SourceConfigTypeDef]


class CreateAlertResponseTypeDef(TypedDict):
    AlertArn: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateAnomalyDetectorResponseTypeDef(TypedDict):
    AnomalyDetectorArn: str
    ResponseMetadata: ResponseMetadataTypeDef


class CreateMetricSetResponseTypeDef(TypedDict):
    MetricSetArn: str
    ResponseMetadata: ResponseMetadataTypeDef


class DescribeAnomalyDetectorResponseTypeDef(TypedDict):
    AnomalyDetectorArn: str
    AnomalyDetectorName: str
    AnomalyDetectorDescription: str
    AnomalyDetectorConfig: AnomalyDetectorConfigSummaryTypeDef
    CreationTime: datetime
    LastModificationTime: datetime
    Status: AnomalyDetectorStatusType
    FailureReason: str
    KmsKeyArn: str
    FailureType: AnomalyDetectorFailureTypeType
    ResponseMetadata: ResponseMetadataTypeDef


class GetSampleDataResponseTypeDef(TypedDict):
    HeaderValues: List[str]
    SampleRows: List[List[str]]
    ResponseMetadata: ResponseMetadataTypeDef


class ListAlertsResponseTypeDef(TypedDict):
    AlertSummaryList: List[AlertSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListAnomalyDetectorsResponseTypeDef(TypedDict):
    AnomalyDetectorSummaryList: List[AnomalyDetectorSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListTagsForResourceResponseTypeDef(TypedDict):
    Tags: Dict[str, str]
    ResponseMetadata: ResponseMetadataTypeDef


class UpdateAlertResponseTypeDef(TypedDict):
    AlertArn: str
    ResponseMetadata: ResponseMetadataTypeDef


class UpdateAnomalyDetectorResponseTypeDef(TypedDict):
    AnomalyDetectorArn: str
    ResponseMetadata: ResponseMetadataTypeDef


class UpdateMetricSetResponseTypeDef(TypedDict):
    MetricSetArn: str
    ResponseMetadata: ResponseMetadataTypeDef


CsvFormatDescriptorUnionTypeDef = Union[
    CsvFormatDescriptorTypeDef, CsvFormatDescriptorOutputTypeDef
]


class MetricSetDataQualityMetricTypeDef(TypedDict):
    MetricSetArn: NotRequired[str]
    DataQualityMetricList: NotRequired[List[DataQualityMetricTypeDef]]


class DescribeAnomalyDetectionExecutionsResponseTypeDef(TypedDict):
    ExecutionList: List[ExecutionStatusTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class DimensionContributionTypeDef(TypedDict):
    DimensionName: NotRequired[str]
    DimensionValueContributionList: NotRequired[List[DimensionValueContributionTypeDef]]


class TimeSeriesTypeDef(TypedDict):
    TimeSeriesId: str
    DimensionList: List[DimensionNameValueTypeDef]
    MetricValueList: List[float]


class FileFormatDescriptorOutputTypeDef(TypedDict):
    CsvFormatDescriptor: NotRequired[CsvFormatDescriptorOutputTypeDef]
    JsonFormatDescriptor: NotRequired[JsonFormatDescriptorTypeDef]


class MetricSetDimensionFilterOutputTypeDef(TypedDict):
    Name: NotRequired[str]
    FilterList: NotRequired[List[FilterTypeDef]]


class MetricSetDimensionFilterTypeDef(TypedDict):
    Name: NotRequired[str]
    FilterList: NotRequired[Sequence[FilterTypeDef]]


class GetFeedbackResponseTypeDef(TypedDict):
    AnomalyGroupTimeSeriesFeedback: List[TimeSeriesFeedbackTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListAnomalyGroupRelatedMetricsResponseTypeDef(TypedDict):
    InterMetricImpactList: List[InterMetricImpactDetailsTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class ListMetricSetsResponseTypeDef(TypedDict):
    MetricSetSummaryList: List[MetricSetSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class RDSSourceConfigOutputTypeDef(TypedDict):
    DBInstanceIdentifier: NotRequired[str]
    DatabaseHost: NotRequired[str]
    DatabasePort: NotRequired[int]
    SecretManagerArn: NotRequired[str]
    DatabaseName: NotRequired[str]
    TableName: NotRequired[str]
    RoleArn: NotRequired[str]
    VpcConfiguration: NotRequired[VpcConfigurationOutputTypeDef]


class RedshiftSourceConfigOutputTypeDef(TypedDict):
    ClusterIdentifier: NotRequired[str]
    DatabaseHost: NotRequired[str]
    DatabasePort: NotRequired[int]
    SecretManagerArn: NotRequired[str]
    DatabaseName: NotRequired[str]
    TableName: NotRequired[str]
    RoleArn: NotRequired[str]
    VpcConfiguration: NotRequired[VpcConfigurationOutputTypeDef]


class RDSSourceConfigTypeDef(TypedDict):
    DBInstanceIdentifier: NotRequired[str]
    DatabaseHost: NotRequired[str]
    DatabasePort: NotRequired[int]
    SecretManagerArn: NotRequired[str]
    DatabaseName: NotRequired[str]
    TableName: NotRequired[str]
    RoleArn: NotRequired[str]
    VpcConfiguration: NotRequired[VpcConfigurationTypeDef]


class RedshiftSourceConfigTypeDef(TypedDict):
    ClusterIdentifier: NotRequired[str]
    DatabaseHost: NotRequired[str]
    DatabasePort: NotRequired[int]
    SecretManagerArn: NotRequired[str]
    DatabaseName: NotRequired[str]
    TableName: NotRequired[str]
    RoleArn: NotRequired[str]
    VpcConfiguration: NotRequired[VpcConfigurationTypeDef]


class AlertTypeDef(TypedDict):
    Action: NotRequired[ActionTypeDef]
    AlertDescription: NotRequired[str]
    AlertArn: NotRequired[str]
    AnomalyDetectorArn: NotRequired[str]
    AlertName: NotRequired[str]
    AlertSensitivityThreshold: NotRequired[int]
    AlertType: NotRequired[AlertTypeType]
    AlertStatus: NotRequired[AlertStatusType]
    LastModificationTime: NotRequired[datetime]
    CreationTime: NotRequired[datetime]
    AlertFilters: NotRequired[AlertFiltersOutputTypeDef]


AlertFiltersUnionTypeDef = Union[AlertFiltersTypeDef, AlertFiltersOutputTypeDef]


class ListAnomalyGroupSummariesResponseTypeDef(TypedDict):
    AnomalyGroupSummaryList: List[AnomalyGroupSummaryTypeDef]
    AnomalyGroupStatistics: AnomalyGroupStatisticsTypeDef
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class DetectedCsvFormatDescriptorTypeDef(TypedDict):
    FileCompression: NotRequired[DetectedFieldTypeDef]
    Charset: NotRequired[DetectedFieldTypeDef]
    ContainsHeader: NotRequired[DetectedFieldTypeDef]
    Delimiter: NotRequired[DetectedFieldTypeDef]
    HeaderList: NotRequired[DetectedFieldTypeDef]
    QuoteSymbol: NotRequired[DetectedFieldTypeDef]


class DetectedJsonFormatDescriptorTypeDef(TypedDict):
    FileCompression: NotRequired[DetectedFieldTypeDef]
    Charset: NotRequired[DetectedFieldTypeDef]


class DetectMetricSetConfigRequestTypeDef(TypedDict):
    AnomalyDetectorArn: str
    AutoDetectionMetricSource: AutoDetectionMetricSourceTypeDef


class FileFormatDescriptorTypeDef(TypedDict):
    CsvFormatDescriptor: NotRequired[CsvFormatDescriptorUnionTypeDef]
    JsonFormatDescriptor: NotRequired[JsonFormatDescriptorTypeDef]


class AnomalyDetectorDataQualityMetricTypeDef(TypedDict):
    StartTimestamp: NotRequired[datetime]
    MetricSetDataQualityMetricList: NotRequired[List[MetricSetDataQualityMetricTypeDef]]


class ContributionMatrixTypeDef(TypedDict):
    DimensionContributionList: NotRequired[List[DimensionContributionTypeDef]]


class ListAnomalyGroupTimeSeriesResponseTypeDef(TypedDict):
    AnomalyGroupId: str
    MetricName: str
    TimestampList: List[str]
    TimeSeriesList: List[TimeSeriesTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    NextToken: NotRequired[str]


class S3SourceConfigOutputTypeDef(TypedDict):
    RoleArn: NotRequired[str]
    TemplatedPathList: NotRequired[List[str]]
    HistoricalDataPathList: NotRequired[List[str]]
    FileFormatDescriptor: NotRequired[FileFormatDescriptorOutputTypeDef]


MetricSetDimensionFilterUnionTypeDef = Union[
    MetricSetDimensionFilterTypeDef, MetricSetDimensionFilterOutputTypeDef
]


class DescribeAlertResponseTypeDef(TypedDict):
    Alert: AlertTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class CreateAlertRequestTypeDef(TypedDict):
    AlertName: str
    AnomalyDetectorArn: str
    Action: ActionTypeDef
    AlertSensitivityThreshold: NotRequired[int]
    AlertDescription: NotRequired[str]
    Tags: NotRequired[Mapping[str, str]]
    AlertFilters: NotRequired[AlertFiltersUnionTypeDef]


class UpdateAlertRequestTypeDef(TypedDict):
    AlertArn: str
    AlertDescription: NotRequired[str]
    AlertSensitivityThreshold: NotRequired[int]
    Action: NotRequired[ActionTypeDef]
    AlertFilters: NotRequired[AlertFiltersUnionTypeDef]


class DetectedFileFormatDescriptorTypeDef(TypedDict):
    CsvFormatDescriptor: NotRequired[DetectedCsvFormatDescriptorTypeDef]
    JsonFormatDescriptor: NotRequired[DetectedJsonFormatDescriptorTypeDef]


FileFormatDescriptorUnionTypeDef = Union[
    FileFormatDescriptorTypeDef, FileFormatDescriptorOutputTypeDef
]


class S3SourceConfigTypeDef(TypedDict):
    RoleArn: NotRequired[str]
    TemplatedPathList: NotRequired[Sequence[str]]
    HistoricalDataPathList: NotRequired[Sequence[str]]
    FileFormatDescriptor: NotRequired[FileFormatDescriptorTypeDef]


class GetDataQualityMetricsResponseTypeDef(TypedDict):
    AnomalyDetectorDataQualityMetricList: List[AnomalyDetectorDataQualityMetricTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class MetricLevelImpactTypeDef(TypedDict):
    MetricName: NotRequired[str]
    NumTimeSeries: NotRequired[int]
    ContributionMatrix: NotRequired[ContributionMatrixTypeDef]


class MetricSourceOutputTypeDef(TypedDict):
    S3SourceConfig: NotRequired[S3SourceConfigOutputTypeDef]
    AppFlowConfig: NotRequired[AppFlowConfigTypeDef]
    CloudWatchConfig: NotRequired[CloudWatchConfigTypeDef]
    RDSSourceConfig: NotRequired[RDSSourceConfigOutputTypeDef]
    RedshiftSourceConfig: NotRequired[RedshiftSourceConfigOutputTypeDef]
    AthenaSourceConfig: NotRequired[AthenaSourceConfigTypeDef]


class DetectedS3SourceConfigTypeDef(TypedDict):
    FileFormatDescriptor: NotRequired[DetectedFileFormatDescriptorTypeDef]


class SampleDataS3SourceConfigTypeDef(TypedDict):
    RoleArn: str
    FileFormatDescriptor: FileFormatDescriptorUnionTypeDef
    TemplatedPathList: NotRequired[Sequence[str]]
    HistoricalDataPathList: NotRequired[Sequence[str]]


class MetricSourceTypeDef(TypedDict):
    S3SourceConfig: NotRequired[S3SourceConfigTypeDef]
    AppFlowConfig: NotRequired[AppFlowConfigTypeDef]
    CloudWatchConfig: NotRequired[CloudWatchConfigTypeDef]
    RDSSourceConfig: NotRequired[RDSSourceConfigTypeDef]
    RedshiftSourceConfig: NotRequired[RedshiftSourceConfigTypeDef]
    AthenaSourceConfig: NotRequired[AthenaSourceConfigTypeDef]


class AnomalyGroupTypeDef(TypedDict):
    StartTime: NotRequired[str]
    EndTime: NotRequired[str]
    AnomalyGroupId: NotRequired[str]
    AnomalyGroupScore: NotRequired[float]
    PrimaryMetricName: NotRequired[str]
    MetricLevelImpactList: NotRequired[List[MetricLevelImpactTypeDef]]


class DescribeMetricSetResponseTypeDef(TypedDict):
    MetricSetArn: str
    AnomalyDetectorArn: str
    MetricSetName: str
    MetricSetDescription: str
    CreationTime: datetime
    LastModificationTime: datetime
    Offset: int
    MetricList: List[MetricTypeDef]
    TimestampColumn: TimestampColumnTypeDef
    DimensionList: List[str]
    MetricSetFrequency: FrequencyType
    Timezone: str
    MetricSource: MetricSourceOutputTypeDef
    DimensionFilterList: List[MetricSetDimensionFilterOutputTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef


class DetectedMetricSourceTypeDef(TypedDict):
    S3SourceConfig: NotRequired[DetectedS3SourceConfigTypeDef]


class GetSampleDataRequestTypeDef(TypedDict):
    S3SourceConfig: NotRequired[SampleDataS3SourceConfigTypeDef]


MetricSourceUnionTypeDef = Union[MetricSourceTypeDef, MetricSourceOutputTypeDef]


class GetAnomalyGroupResponseTypeDef(TypedDict):
    AnomalyGroup: AnomalyGroupTypeDef
    ResponseMetadata: ResponseMetadataTypeDef


class DetectedMetricSetConfigTypeDef(TypedDict):
    Offset: NotRequired[DetectedFieldTypeDef]
    MetricSetFrequency: NotRequired[DetectedFieldTypeDef]
    MetricSource: NotRequired[DetectedMetricSourceTypeDef]


class CreateMetricSetRequestTypeDef(TypedDict):
    AnomalyDetectorArn: str
    MetricSetName: str
    MetricList: Sequence[MetricTypeDef]
    MetricSource: MetricSourceUnionTypeDef
    MetricSetDescription: NotRequired[str]
    Offset: NotRequired[int]
    TimestampColumn: NotRequired[TimestampColumnTypeDef]
    DimensionList: NotRequired[Sequence[str]]
    MetricSetFrequency: NotRequired[FrequencyType]
    Timezone: NotRequired[str]
    Tags: NotRequired[Mapping[str, str]]
    DimensionFilterList: NotRequired[Sequence[MetricSetDimensionFilterUnionTypeDef]]


class UpdateMetricSetRequestTypeDef(TypedDict):
    MetricSetArn: str
    MetricSetDescription: NotRequired[str]
    MetricList: NotRequired[Sequence[MetricTypeDef]]
    Offset: NotRequired[int]
    TimestampColumn: NotRequired[TimestampColumnTypeDef]
    DimensionList: NotRequired[Sequence[str]]
    MetricSetFrequency: NotRequired[FrequencyType]
    MetricSource: NotRequired[MetricSourceUnionTypeDef]
    DimensionFilterList: NotRequired[Sequence[MetricSetDimensionFilterUnionTypeDef]]


class DetectMetricSetConfigResponseTypeDef(TypedDict):
    DetectedMetricSetConfig: DetectedMetricSetConfigTypeDef
    ResponseMetadata: ResponseMetadataTypeDef
